# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/audittrails/v1/trail.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/audittrails/v1/trail.proto\x12\x1byandex.cloud.audittrails.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x96\x15\n\x05Trail\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x34\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x05 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x06 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12{\n\x06labels\x18\x07 \x03(\x0b\x32..yandex.cloud.audittrails.v1.Trail.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12I\n\x0b\x64\x65stination\x18\x08 \x01(\x0b\x32..yandex.cloud.audittrails.v1.Trail.DestinationB\x04\xe8\xc7\x31\x01\x12$\n\x12service_account_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12?\n\x06status\x18\n \x01(\x0e\x32).yandex.cloud.audittrails.v1.Trail.StatusB\x04\xe8\xc7\x31\x01\x12?\n\x06\x66ilter\x18\x0b \x01(\x0b\x32).yandex.cloud.audittrails.v1.Trail.FilterB\x04\xe8\xc7\x31\x01\x12\x1c\n\x14status_error_message\x18\x0c \x01(\t\x12\x1e\n\x08\x63loud_id\x18\x0e \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x84\x02\n\x0b\x44\x65stination\x12J\n\x0eobject_storage\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.audittrails.v1.Trail.ObjectStorageH\x00\x12H\n\rcloud_logging\x18\x03 \x01(\x0b\x32/.yandex.cloud.audittrails.v1.Trail.CloudLoggingH\x00\x12\x44\n\x0b\x64\x61ta_stream\x18\x04 \x01(\x0b\x32-.yandex.cloud.audittrails.v1.Trail.DataStreamH\x00\x42\x13\n\x0b\x64\x65stination\x12\x04\xc0\xc1\x31\x01J\x04\x08\x02\x10\x03\x1a\x43\n\rObjectStorage\x12\x1b\n\tbucket_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04\x33-63\x12\x15\n\robject_prefix\x18\x02 \x01(\t\x1a\x45\n\x0c\x43loudLogging\x12 \n\x0clog_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=64H\x00\x42\r\n\x0b\x64\x65stinationJ\x04\x08\x02\x10\x03\x1a\x36\n\nDataStream\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x1a\x98\x01\n\x06\x46ilter\x12\x42\n\x0bpath_filter\x18\x01 \x01(\x0b\x32-.yandex.cloud.audittrails.v1.Trail.PathFilter\x12J\n\x0c\x65vent_filter\x18\x02 \x01(\x0b\x32..yandex.cloud.audittrails.v1.Trail.EventFilterB\x04\xe8\xc7\x31\x01\x1aV\n\nPathFilter\x12H\n\x04root\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.audittrails.v1.Trail.PathFilterElementB\x04\xe8\xc7\x31\x01\x1a\xc4\x01\n\x11PathFilterElement\x12M\n\nany_filter\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.audittrails.v1.Trail.PathFilterElementAnyH\x00\x12O\n\x0bsome_filter\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.audittrails.v1.Trail.PathFilterElementSomeH\x00\x42\x0f\n\x07\x65lement\x12\x04\xc0\xc1\x31\x01\x1a[\n\x14PathFilterElementAny\x12\x43\n\x08resource\x18\x01 \x01(\x0b\x32+.yandex.cloud.audittrails.v1.Trail.ResourceB\x04\xe8\xc7\x31\x01\x1a\xab\x01\n\x15PathFilterElementSome\x12\x43\n\x08resource\x18\x01 \x01(\x0b\x32+.yandex.cloud.audittrails.v1.Trail.ResourceB\x04\xe8\xc7\x31\x01\x12M\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.audittrails.v1.Trail.PathFilterElementB\x06\x82\xc8\x31\x02>0\x1a@\n\x08Resource\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1a\n\x04type\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x1a^\n\x0b\x45ventFilter\x12O\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.audittrails.v1.Trail.EventFilterElementB\x07\x82\xc8\x31\x03>=0\x1a\xd0\x01\n\x12\x45ventFilterElement\x12\x15\n\x07service\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12Y\n\ncategories\x18\x02 \x03(\x0b\x32=.yandex.cloud.audittrails.v1.Trail.EventFilterElementCategoryB\x06\x82\xc8\x31\x02>0\x12H\n\x0bpath_filter\x18\x03 \x01(\x0b\x32-.yandex.cloud.audittrails.v1.Trail.PathFilterB\x04\xe8\xc7\x31\x01\x1a\xb7\x01\n\x1a\x45ventFilterElementCategory\x12K\n\x05plane\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.audittrails.v1.Trail.EventCategoryFilterB\x04\xe8\xc7\x31\x01\x12L\n\x04type\x18\x02 \x01(\x0e\x32\x38.yandex.cloud.audittrails.v1.Trail.EventAccessTypeFilterB\x04\xe8\xc7\x31\x01\"D\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\"_\n\x13\x45ventCategoryFilter\x12%\n!EVENT_CATEGORY_FILTER_UNSPECIFIED\x10\x00\x12\x11\n\rCONTROL_PLANE\x10\x01\x12\x0e\n\nDATA_PLANE\x10\x02\"V\n\x15\x45ventAccessTypeFilter\x12(\n$EVENT_ACCESS_TYPE_FILTER_UNSPECIFIED\x10\x00\x12\t\n\x05WRITE\x10\x01\x12\x08\n\x04READ\x10\x02J\x04\x08\r\x10\x0e\x42r\n\x1fyandex.cloud.api.audittrails.v1B\x02\x41TZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/audittrails/v1;audittrailsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.audittrails.v1.trail_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.audittrails.v1B\002ATZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/audittrails/v1;audittrails'
  _TRAIL_LABELSENTRY._options = None
  _TRAIL_LABELSENTRY._serialized_options = b'8\001'
  _TRAIL_DESTINATION.oneofs_by_name['destination']._options = None
  _TRAIL_DESTINATION.oneofs_by_name['destination']._serialized_options = b'\300\3011\001'
  _TRAIL_OBJECTSTORAGE.fields_by_name['bucket_id']._options = None
  _TRAIL_OBJECTSTORAGE.fields_by_name['bucket_id']._serialized_options = b'\212\3101\0043-63'
  _TRAIL_CLOUDLOGGING.fields_by_name['log_group_id']._options = None
  _TRAIL_CLOUDLOGGING.fields_by_name['log_group_id']._serialized_options = b'\212\3101\004<=64'
  _TRAIL_FILTER.fields_by_name['event_filter']._options = None
  _TRAIL_FILTER.fields_by_name['event_filter']._serialized_options = b'\350\3071\001'
  _TRAIL_PATHFILTER.fields_by_name['root']._options = None
  _TRAIL_PATHFILTER.fields_by_name['root']._serialized_options = b'\350\3071\001'
  _TRAIL_PATHFILTERELEMENT.oneofs_by_name['element']._options = None
  _TRAIL_PATHFILTERELEMENT.oneofs_by_name['element']._serialized_options = b'\300\3011\001'
  _TRAIL_PATHFILTERELEMENTANY.fields_by_name['resource']._options = None
  _TRAIL_PATHFILTERELEMENTANY.fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _TRAIL_PATHFILTERELEMENTSOME.fields_by_name['resource']._options = None
  _TRAIL_PATHFILTERELEMENTSOME.fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _TRAIL_PATHFILTERELEMENTSOME.fields_by_name['filters']._options = None
  _TRAIL_PATHFILTERELEMENTSOME.fields_by_name['filters']._serialized_options = b'\202\3101\002>0'
  _TRAIL_RESOURCE.fields_by_name['id']._options = None
  _TRAIL_RESOURCE.fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _TRAIL_RESOURCE.fields_by_name['type']._options = None
  _TRAIL_RESOURCE.fields_by_name['type']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _TRAIL_EVENTFILTER.fields_by_name['filters']._options = None
  _TRAIL_EVENTFILTER.fields_by_name['filters']._serialized_options = b'\202\3101\003>=0'
  _TRAIL_EVENTFILTERELEMENT.fields_by_name['service']._options = None
  _TRAIL_EVENTFILTERELEMENT.fields_by_name['service']._serialized_options = b'\350\3071\001'
  _TRAIL_EVENTFILTERELEMENT.fields_by_name['categories']._options = None
  _TRAIL_EVENTFILTERELEMENT.fields_by_name['categories']._serialized_options = b'\202\3101\002>0'
  _TRAIL_EVENTFILTERELEMENT.fields_by_name['path_filter']._options = None
  _TRAIL_EVENTFILTERELEMENT.fields_by_name['path_filter']._serialized_options = b'\350\3071\001'
  _TRAIL_EVENTFILTERELEMENTCATEGORY.fields_by_name['plane']._options = None
  _TRAIL_EVENTFILTERELEMENTCATEGORY.fields_by_name['plane']._serialized_options = b'\350\3071\001'
  _TRAIL_EVENTFILTERELEMENTCATEGORY.fields_by_name['type']._options = None
  _TRAIL_EVENTFILTERELEMENTCATEGORY.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _TRAIL.fields_by_name['folder_id']._options = None
  _TRAIL.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _TRAIL.fields_by_name['created_at']._options = None
  _TRAIL.fields_by_name['created_at']._serialized_options = b'\350\3071\001'
  _TRAIL.fields_by_name['updated_at']._options = None
  _TRAIL.fields_by_name['updated_at']._serialized_options = b'\350\3071\001'
  _TRAIL.fields_by_name['name']._options = None
  _TRAIL.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _TRAIL.fields_by_name['description']._options = None
  _TRAIL.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _TRAIL.fields_by_name['labels']._options = None
  _TRAIL.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _TRAIL.fields_by_name['destination']._options = None
  _TRAIL.fields_by_name['destination']._serialized_options = b'\350\3071\001'
  _TRAIL.fields_by_name['service_account_id']._options = None
  _TRAIL.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _TRAIL.fields_by_name['status']._options = None
  _TRAIL.fields_by_name['status']._serialized_options = b'\350\3071\001'
  _TRAIL.fields_by_name['filter']._options = None
  _TRAIL.fields_by_name['filter']._serialized_options = b'\350\3071\001'
  _TRAIL.fields_by_name['cloud_id']._options = None
  _TRAIL.fields_by_name['cloud_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TRAIL']._serialized_start=137
  _globals['_TRAIL']._serialized_end=2847
  _globals['_TRAIL_LABELSENTRY']._serialized_start=814
  _globals['_TRAIL_LABELSENTRY']._serialized_end=859
  _globals['_TRAIL_DESTINATION']._serialized_start=862
  _globals['_TRAIL_DESTINATION']._serialized_end=1122
  _globals['_TRAIL_OBJECTSTORAGE']._serialized_start=1124
  _globals['_TRAIL_OBJECTSTORAGE']._serialized_end=1191
  _globals['_TRAIL_CLOUDLOGGING']._serialized_start=1193
  _globals['_TRAIL_CLOUDLOGGING']._serialized_end=1262
  _globals['_TRAIL_DATASTREAM']._serialized_start=1264
  _globals['_TRAIL_DATASTREAM']._serialized_end=1318
  _globals['_TRAIL_FILTER']._serialized_start=1321
  _globals['_TRAIL_FILTER']._serialized_end=1473
  _globals['_TRAIL_PATHFILTER']._serialized_start=1475
  _globals['_TRAIL_PATHFILTER']._serialized_end=1561
  _globals['_TRAIL_PATHFILTERELEMENT']._serialized_start=1564
  _globals['_TRAIL_PATHFILTERELEMENT']._serialized_end=1760
  _globals['_TRAIL_PATHFILTERELEMENTANY']._serialized_start=1762
  _globals['_TRAIL_PATHFILTERELEMENTANY']._serialized_end=1853
  _globals['_TRAIL_PATHFILTERELEMENTSOME']._serialized_start=1856
  _globals['_TRAIL_PATHFILTERELEMENTSOME']._serialized_end=2027
  _globals['_TRAIL_RESOURCE']._serialized_start=2029
  _globals['_TRAIL_RESOURCE']._serialized_end=2093
  _globals['_TRAIL_EVENTFILTER']._serialized_start=2095
  _globals['_TRAIL_EVENTFILTER']._serialized_end=2189
  _globals['_TRAIL_EVENTFILTERELEMENT']._serialized_start=2192
  _globals['_TRAIL_EVENTFILTERELEMENT']._serialized_end=2400
  _globals['_TRAIL_EVENTFILTERELEMENTCATEGORY']._serialized_start=2403
  _globals['_TRAIL_EVENTFILTERELEMENTCATEGORY']._serialized_end=2586
  _globals['_TRAIL_STATUS']._serialized_start=2588
  _globals['_TRAIL_STATUS']._serialized_end=2656
  _globals['_TRAIL_EVENTCATEGORYFILTER']._serialized_start=2658
  _globals['_TRAIL_EVENTCATEGORYFILTER']._serialized_end=2753
  _globals['_TRAIL_EVENTACCESSTYPEFILTER']._serialized_start=2755
  _globals['_TRAIL_EVENTACCESSTYPEFILTER']._serialized_end=2841
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.speechsense.v1 import talk_service_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2


class TalkServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UploadAsStream = channel.stream_unary(
                '/yandex.cloud.speechsense.v1.TalkService/UploadAsStream',
                request_serializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.StreamTalkRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTalkResponse.FromString,
                )
        self.Upload = channel.unary_unary(
                '/yandex.cloud.speechsense.v1.TalkService/Upload',
                request_serializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTalkRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTalkResponse.FromString,
                )
        self.UploadText = channel.unary_unary(
                '/yandex.cloud.speechsense.v1.TalkService/UploadText',
                request_serializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTextRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTextResponse.FromString,
                )


class TalkServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UploadAsStream(self, request_iterator, context):
        """rpc for streaming talk documents. First message should contain Talk related metadata,
        second - audio metadata, others should contain audio bytes in chunks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Upload(self, request, context):
        """rpc for uploading talk document as single message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadText(self, request, context):
        """rpc for uploading text talk document
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TalkServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UploadAsStream': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadAsStream,
                    request_deserializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.StreamTalkRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTalkResponse.SerializeToString,
            ),
            'Upload': grpc.unary_unary_rpc_method_handler(
                    servicer.Upload,
                    request_deserializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTalkRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTalkResponse.SerializeToString,
            ),
            'UploadText': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadText,
                    request_deserializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTextRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTextResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.speechsense.v1.TalkService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TalkService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UploadAsStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/yandex.cloud.speechsense.v1.TalkService/UploadAsStream',
            yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.StreamTalkRequest.SerializeToString,
            yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTalkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Upload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.speechsense.v1.TalkService/Upload',
            yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTalkRequest.SerializeToString,
            yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTalkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.speechsense.v1.TalkService/UploadText',
            yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTextRequest.SerializeToString,
            yandex_dot_cloud_dot_speechsense_dot_v1_dot_talk__service__pb2.UploadTextResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/backup/v1/policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/backup/v1/policy.proto\x12\x16yandex.cloud.backup.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xfc\x01\n\x06Policy\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x38\n\x08settings\x18\x06 \x01(\x0b\x32&.yandex.cloud.backup.v1.PolicySettings\x12\x11\n\tfolder_id\x18\x07 \x01(\t\"\xaf \n\x0ePolicySettings\x12M\n\x0b\x63ompression\x18\x01 \x01(\x0e\x32\x32.yandex.cloud.backup.v1.PolicySettings.CompressionB\x04\xe8\xc7\x31\x01\x12\x34\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x1e.yandex.cloud.backup.v1.FormatB\x04\xe8\xc7\x31\x01\x12)\n!multi_volume_snapshotting_enabled\x18\x03 \x01(\x08\x12\'\n\x1fpreserve_file_security_settings\x18\x04 \x01(\x08\x12U\n\nreattempts\x18\x05 \x01(\x0b\x32;.yandex.cloud.backup.v1.PolicySettings.RetriesConfigurationB\x04\xe8\xc7\x31\x01\x12\x1b\n\x13silent_mode_enabled\x18\x06 \x01(\x08\x12I\n\tsplitting\x18\x07 \x01(\x0b\x32\x30.yandex.cloud.backup.v1.PolicySettings.SplittingB\x04\xe8\xc7\x31\x01\x12\x61\n\x16vm_snapshot_reattempts\x18\x08 \x01(\x0b\x32;.yandex.cloud.backup.v1.PolicySettings.RetriesConfigurationB\x04\xe8\xc7\x31\x01\x12Y\n\x03vss\x18\t \x01(\x0b\x32\x46.yandex.cloud.backup.v1.PolicySettings.VolumeShadowCopyServiceSettingsB\x04\xe8\xc7\x31\x01\x12I\n\x07\x61rchive\x18\n \x01(\x0b\x32\x38.yandex.cloud.backup.v1.PolicySettings.ArchiveProperties\x12Z\n\x12performance_window\x18\x0b \x01(\x0b\x32\x38.yandex.cloud.backup.v1.PolicySettings.PerformanceWindowB\x04\xe8\xc7\x31\x01\x12I\n\tretention\x18\x0c \x01(\x0b\x32\x30.yandex.cloud.backup.v1.PolicySettings.RetentionB\x04\xe8\xc7\x31\x01\x12K\n\nscheduling\x18\x0f \x01(\x0b\x32\x31.yandex.cloud.backup.v1.PolicySettings.SchedulingB\x04\xe8\xc7\x31\x01\x12N\n\x03\x63\x62t\x18\x10 \x01(\x0e\x32;.yandex.cloud.backup.v1.PolicySettings.ChangedBlockTrackingB\x04\xe8\xc7\x31\x01\x12\x1b\n\x13\x66\x61st_backup_enabled\x18\x11 \x01(\x08\x12$\n\x1cquiesce_snapshotting_enabled\x18\x12 \x01(\x08\x1a\xcf\x01\n\x08Interval\x12H\n\x04type\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.backup.v1.PolicySettings.Interval.TypeB\x04\xe8\xc7\x31\x01\x12\x15\n\x05\x63ount\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"b\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SECONDS\x10\x01\x12\x0b\n\x07MINUTES\x10\x02\x12\t\n\x05HOURS\x10\x03\x12\x08\n\x04\x44\x41YS\x10\x04\x12\t\n\x05WEEKS\x10\x05\x12\n\n\x06MONTHS\x10\x06\x1a\x8e\x01\n\x14RetriesConfiguration\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12G\n\x08interval\x18\x02 \x01(\x0b\x32/.yandex.cloud.backup.v1.PolicySettings.IntervalB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0cmax_attempts\x18\x03 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x1a\x19\n\tSplitting\x12\x0c\n\x04size\x18\x01 \x01(\x03\x1a\xf2\x01\n\x1fVolumeShadowCopyServiceSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12j\n\x08provider\x18\x02 \x01(\x0e\x32R.yandex.cloud.backup.v1.PolicySettings.VolumeShadowCopyServiceSettings.VSSProviderB\x04\xe8\xc7\x31\x01\"R\n\x0bVSSProvider\x12\x1c\n\x18VSS_PROVIDER_UNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x19\n\x15TARGET_SYSTEM_DEFINED\x10\x02\x1a!\n\x11\x41rchiveProperties\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a$\n\x11PerformanceWindow\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x1a)\n\tTimeOfDay\x12\x0c\n\x04hour\x18\x01 \x01(\x03\x12\x0e\n\x06minute\x18\x02 \x01(\x03\x1a\xbf\x02\n\tRetention\x12M\n\x05rules\x18\x01 \x03(\x0b\x32>.yandex.cloud.backup.v1.PolicySettings.Retention.RetentionRule\x12\x15\n\rbefore_backup\x18\x03 \x01(\x08\x1a\xc5\x01\n\rRetentionRule\x12H\n\nbackup_set\x18\x01 \x03(\x0e\x32\x34.yandex.cloud.backup.v1.PolicySettings.RepeatePeriod\x12\x42\n\x07max_age\x18\x02 \x01(\x0b\x32/.yandex.cloud.backup.v1.PolicySettings.IntervalH\x00\x12\x13\n\tmax_count\x18\x03 \x01(\x03H\x00\x42\x11\n\tcondition\x12\x04\xc0\xc1\x31\x01J\x04\x08\x02\x10\x03\x1a\x9a\x0c\n\nScheduling\x12X\n\x0b\x62\x61\x63kup_sets\x18\x01 \x03(\x0b\x32;.yandex.cloud.backup.v1.PolicySettings.Scheduling.BackupSetB\x06\x82\xc8\x31\x02>0\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x1c\n\x14max_parallel_backups\x18\x03 \x01(\x03\x12M\n\x0erand_max_delay\x18\x04 \x01(\x0b\x32/.yandex.cloud.backup.v1.PolicySettings.IntervalB\x04\xe8\xc7\x31\x01\x12N\n\x06scheme\x18\x05 \x01(\x0e\x32\x38.yandex.cloud.backup.v1.PolicySettings.Scheduling.SchemeB\x04\xe8\xc7\x31\x01\x12K\n\x11weekly_backup_day\x18\x06 \x01(\x0e\x32*.yandex.cloud.backup.v1.PolicySettings.DayB\x04\xe8\xc7\x31\x01\x1a\xee\x07\n\tBackupSet\x12P\n\x04time\x18\x01 \x01(\x0b\x32@.yandex.cloud.backup.v1.PolicySettings.Scheduling.BackupSet.TimeH\x00\x12m\n\x14since_last_exec_time\x18\x02 \x01(\x0b\x32M.yandex.cloud.backup.v1.PolicySettings.Scheduling.BackupSet.SinceLastExecTimeH\x00\x12N\n\x04type\x18\x03 \x01(\x0e\x32@.yandex.cloud.backup.v1.PolicySettings.Scheduling.BackupSet.Type\x1a\xfa\x03\n\x04Time\x12\x42\n\x08weekdays\x18\x01 \x03(\x0e\x32*.yandex.cloud.backup.v1.PolicySettings.DayB\x04\x90\xc8\x31\x01\x12\x43\n\trepeat_at\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.backup.v1.PolicySettings.TimeOfDay\x12\x45\n\x0crepeat_every\x18\x03 \x01(\x0b\x32/.yandex.cloud.backup.v1.PolicySettings.Interval\x12\x43\n\ttime_from\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.backup.v1.PolicySettings.TimeOfDay\x12\x41\n\x07time_to\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.backup.v1.PolicySettings.TimeOfDay\x12\x17\n\tmonthdays\x18\x06 \x03(\x03\x42\x04\x90\xc8\x31\x01\x12!\n\x19include_last_day_of_month\x18\x07 \x01(\x08\x12\x14\n\x06months\x18\x08 \x03(\x03\x42\x04\x90\xc8\x31\x01\x12H\n\x04type\x18\t \x01(\x0e\x32\x34.yandex.cloud.backup.v1.PolicySettings.RepeatePeriodB\x04\xe8\xc7\x31\x01\x1aY\n\x11SinceLastExecTime\x12\x44\n\x05\x64\x65lay\x18\x01 \x01(\x0b\x32/.yandex.cloud.backup.v1.PolicySettings.IntervalB\x04\xe8\xc7\x31\x01\"g\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tTYPE_AUTO\x10\x01\x12\r\n\tTYPE_FULL\x10\x02\x12\x14\n\x10TYPE_INCREMENTAL\x10\x03\x12\x15\n\x11TYPE_DIFFERENTIAL\x10\x04\x42\x0f\n\x07setting\x12\x04\xc0\xc1\x31\x01\"\xa5\x01\n\x06Scheme\x12\x16\n\x12SCHEME_UNSPECIFIED\x10\x00\x12\n\n\x06SIMPLE\x10\x01\x12\x0f\n\x0b\x41LWAYS_FULL\x10\x02\x12\x16\n\x12\x41LWAYS_INCREMENTAL\x10\x03\x12\x16\n\x12WEEKLY_INCREMENTAL\x10\x04\x12!\n\x1dWEEKLY_FULL_DAILY_INCREMENTAL\x10\x05\x12\n\n\x06\x43USTOM\x10\x06\x12\x07\n\x03\x43\x44P\x10\x07\"R\n\x0b\x43ompression\x12\x1b\n\x17\x43OMPRESSION_UNSPECIFIED\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03OFF\x10\x04\"_\n\rRepeatePeriod\x12\x1e\n\x1aREPEATE_PERIOD_UNSPECIFIED\x10\x00\x12\n\n\x06HOURLY\x10\x01\x12\t\n\x05\x44\x41ILY\x10\x02\x12\n\n\x06WEEKLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\"v\n\x03\x44\x61y\x12\x13\n\x0f\x44\x41Y_UNSPECIFIED\x10\x00\x12\n\n\x06MONDAY\x10\x01\x12\x0b\n\x07TUESDAY\x10\x02\x12\r\n\tWEDNESDAY\x10\x03\x12\x0c\n\x08THURSDAY\x10\x04\x12\n\n\x06\x46RIDAY\x10\x05\x12\x0c\n\x08SATURDAY\x10\x06\x12\n\n\x06SUNDAY\x10\x07\"v\n\x14\x43hangedBlockTracking\x12&\n\"CHANGED_BLOCK_TRACKING_UNSPECIFIED\x10\x00\x12\x12\n\x0eUSE_IF_ENABLED\x10\x01\x12\x12\n\x0e\x45NABLE_AND_USE\x10\x02\x12\x0e\n\nDO_NOT_USE\x10\x03J\x04\x08\r\x10\x0eJ\x04\x08\x0e\x10\x0f\"\x8b\x02\n\x11PolicyApplication\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12@\n\x06status\x18\x04 \x01(\x0e\x32\x30.yandex.cloud.backup.v1.PolicyApplication.Status\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"C\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03*J\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0e\n\nVERSION_11\x10\x01\x12\x0e\n\nVERSION_12\x10\x02\x12\x08\n\x04\x41UTO\x10\x03\x42_\n\x1ayandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.backup.v1.policy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backup'
  _POLICY.fields_by_name['id']._options = None
  _POLICY.fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _POLICY.fields_by_name['name']._options = None
  _POLICY.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _POLICYSETTINGS_INTERVAL.fields_by_name['type']._options = None
  _POLICYSETTINGS_INTERVAL.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS_INTERVAL.fields_by_name['count']._options = None
  _POLICYSETTINGS_INTERVAL.fields_by_name['count']._serialized_options = b'\372\3071\002>0'
  _POLICYSETTINGS_RETRIESCONFIGURATION.fields_by_name['interval']._options = None
  _POLICYSETTINGS_RETRIESCONFIGURATION.fields_by_name['interval']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS_RETRIESCONFIGURATION.fields_by_name['max_attempts']._options = None
  _POLICYSETTINGS_RETRIESCONFIGURATION.fields_by_name['max_attempts']._serialized_options = b'\372\3071\002>0'
  _POLICYSETTINGS_VOLUMESHADOWCOPYSERVICESETTINGS.fields_by_name['provider']._options = None
  _POLICYSETTINGS_VOLUMESHADOWCOPYSERVICESETTINGS.fields_by_name['provider']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS_RETENTION_RETENTIONRULE.oneofs_by_name['condition']._options = None
  _POLICYSETTINGS_RETENTION_RETENTIONRULE.oneofs_by_name['condition']._serialized_options = b'\300\3011\001'
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME.fields_by_name['weekdays']._options = None
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME.fields_by_name['weekdays']._serialized_options = b'\220\3101\001'
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME.fields_by_name['monthdays']._options = None
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME.fields_by_name['monthdays']._serialized_options = b'\220\3101\001'
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME.fields_by_name['months']._options = None
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME.fields_by_name['months']._serialized_options = b'\220\3101\001'
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME.fields_by_name['type']._options = None
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_SINCELASTEXECTIME.fields_by_name['delay']._options = None
  _POLICYSETTINGS_SCHEDULING_BACKUPSET_SINCELASTEXECTIME.fields_by_name['delay']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS_SCHEDULING_BACKUPSET.oneofs_by_name['setting']._options = None
  _POLICYSETTINGS_SCHEDULING_BACKUPSET.oneofs_by_name['setting']._serialized_options = b'\300\3011\001'
  _POLICYSETTINGS_SCHEDULING.fields_by_name['backup_sets']._options = None
  _POLICYSETTINGS_SCHEDULING.fields_by_name['backup_sets']._serialized_options = b'\202\3101\002>0'
  _POLICYSETTINGS_SCHEDULING.fields_by_name['rand_max_delay']._options = None
  _POLICYSETTINGS_SCHEDULING.fields_by_name['rand_max_delay']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS_SCHEDULING.fields_by_name['scheme']._options = None
  _POLICYSETTINGS_SCHEDULING.fields_by_name['scheme']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS_SCHEDULING.fields_by_name['weekly_backup_day']._options = None
  _POLICYSETTINGS_SCHEDULING.fields_by_name['weekly_backup_day']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['compression']._options = None
  _POLICYSETTINGS.fields_by_name['compression']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['format']._options = None
  _POLICYSETTINGS.fields_by_name['format']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['reattempts']._options = None
  _POLICYSETTINGS.fields_by_name['reattempts']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['splitting']._options = None
  _POLICYSETTINGS.fields_by_name['splitting']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['vm_snapshot_reattempts']._options = None
  _POLICYSETTINGS.fields_by_name['vm_snapshot_reattempts']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['vss']._options = None
  _POLICYSETTINGS.fields_by_name['vss']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['performance_window']._options = None
  _POLICYSETTINGS.fields_by_name['performance_window']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['retention']._options = None
  _POLICYSETTINGS.fields_by_name['retention']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['scheduling']._options = None
  _POLICYSETTINGS.fields_by_name['scheduling']._serialized_options = b'\350\3071\001'
  _POLICYSETTINGS.fields_by_name['cbt']._options = None
  _POLICYSETTINGS.fields_by_name['cbt']._serialized_options = b'\350\3071\001'
  _globals['_FORMAT']._serialized_start=4798
  _globals['_FORMAT']._serialized_end=4872
  _globals['_POLICY']._serialized_start=128
  _globals['_POLICY']._serialized_end=380
  _globals['_POLICYSETTINGS']._serialized_start=383
  _globals['_POLICYSETTINGS']._serialized_end=4526
  _globals['_POLICYSETTINGS_INTERVAL']._serialized_start=1466
  _globals['_POLICYSETTINGS_INTERVAL']._serialized_end=1673
  _globals['_POLICYSETTINGS_INTERVAL_TYPE']._serialized_start=1575
  _globals['_POLICYSETTINGS_INTERVAL_TYPE']._serialized_end=1673
  _globals['_POLICYSETTINGS_RETRIESCONFIGURATION']._serialized_start=1676
  _globals['_POLICYSETTINGS_RETRIESCONFIGURATION']._serialized_end=1818
  _globals['_POLICYSETTINGS_SPLITTING']._serialized_start=1820
  _globals['_POLICYSETTINGS_SPLITTING']._serialized_end=1845
  _globals['_POLICYSETTINGS_VOLUMESHADOWCOPYSERVICESETTINGS']._serialized_start=1848
  _globals['_POLICYSETTINGS_VOLUMESHADOWCOPYSERVICESETTINGS']._serialized_end=2090
  _globals['_POLICYSETTINGS_VOLUMESHADOWCOPYSERVICESETTINGS_VSSPROVIDER']._serialized_start=2008
  _globals['_POLICYSETTINGS_VOLUMESHADOWCOPYSERVICESETTINGS_VSSPROVIDER']._serialized_end=2090
  _globals['_POLICYSETTINGS_ARCHIVEPROPERTIES']._serialized_start=2092
  _globals['_POLICYSETTINGS_ARCHIVEPROPERTIES']._serialized_end=2125
  _globals['_POLICYSETTINGS_PERFORMANCEWINDOW']._serialized_start=2127
  _globals['_POLICYSETTINGS_PERFORMANCEWINDOW']._serialized_end=2163
  _globals['_POLICYSETTINGS_TIMEOFDAY']._serialized_start=2165
  _globals['_POLICYSETTINGS_TIMEOFDAY']._serialized_end=2206
  _globals['_POLICYSETTINGS_RETENTION']._serialized_start=2209
  _globals['_POLICYSETTINGS_RETENTION']._serialized_end=2528
  _globals['_POLICYSETTINGS_RETENTION_RETENTIONRULE']._serialized_start=2325
  _globals['_POLICYSETTINGS_RETENTION_RETENTIONRULE']._serialized_end=2522
  _globals['_POLICYSETTINGS_SCHEDULING']._serialized_start=2531
  _globals['_POLICYSETTINGS_SCHEDULING']._serialized_end=4093
  _globals['_POLICYSETTINGS_SCHEDULING_BACKUPSET']._serialized_start=2919
  _globals['_POLICYSETTINGS_SCHEDULING_BACKUPSET']._serialized_end=3925
  _globals['_POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME']._serialized_start=3206
  _globals['_POLICYSETTINGS_SCHEDULING_BACKUPSET_TIME']._serialized_end=3712
  _globals['_POLICYSETTINGS_SCHEDULING_BACKUPSET_SINCELASTEXECTIME']._serialized_start=3714
  _globals['_POLICYSETTINGS_SCHEDULING_BACKUPSET_SINCELASTEXECTIME']._serialized_end=3803
  _globals['_POLICYSETTINGS_SCHEDULING_BACKUPSET_TYPE']._serialized_start=3805
  _globals['_POLICYSETTINGS_SCHEDULING_BACKUPSET_TYPE']._serialized_end=3908
  _globals['_POLICYSETTINGS_SCHEDULING_SCHEME']._serialized_start=3928
  _globals['_POLICYSETTINGS_SCHEDULING_SCHEME']._serialized_end=4093
  _globals['_POLICYSETTINGS_COMPRESSION']._serialized_start=4095
  _globals['_POLICYSETTINGS_COMPRESSION']._serialized_end=4177
  _globals['_POLICYSETTINGS_REPEATEPERIOD']._serialized_start=4179
  _globals['_POLICYSETTINGS_REPEATEPERIOD']._serialized_end=4274
  _globals['_POLICYSETTINGS_DAY']._serialized_start=4276
  _globals['_POLICYSETTINGS_DAY']._serialized_end=4394
  _globals['_POLICYSETTINGS_CHANGEDBLOCKTRACKING']._serialized_start=4396
  _globals['_POLICYSETTINGS_CHANGEDBLOCKTRACKING']._serialized_end=4514
  _globals['_POLICYAPPLICATION']._serialized_start=4529
  _globals['_POLICYAPPLICATION']._serialized_end=4796
  _globals['_POLICYAPPLICATION_STATUS']._serialized_start=4729
  _globals['_POLICYAPPLICATION_STATUS']._serialized_end=4796
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/test_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.loadtesting.api.v1.test import single_agent_configuration_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_single__agent__configuration__pb2
from yandex.cloud.loadtesting.api.v1.test import details_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_details__pb2
from yandex.cloud.loadtesting.api.v1.test import test_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_test__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/loadtesting/api/v1/test_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/api/operation.proto\x1a\x45yandex/cloud/loadtesting/api/v1/test/single_agent_configuration.proto\x1a\x32yandex/cloud/loadtesting/api/v1/test/details.proto\x1a/yandex/cloud/loadtesting/api/v1/test/test.proto\x1a\x1dyandex/cloud/validation.proto\"\xd1\x01\n\x11\x43reateTestRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12V\n\x0e\x63onfigurations\x18\x02 \x03(\x0b\x32>.yandex.cloud.loadtesting.api.v1.test.SingleAgentConfiguration\x12\x43\n\x0ctest_details\x18\x03 \x01(\x0b\x32-.yandex.cloud.loadtesting.api.v1.test.Details\"%\n\x12\x43reateTestMetadata\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"\'\n\x0eGetTestRequest\x12\x15\n\x07test_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\"\n\x0fStopTestRequest\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"#\n\x10StopTestMetadata\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"$\n\x11\x44\x65leteTestRequest\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"%\n\x12\x44\x65leteTestMetadata\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"\\\n\x10ListTestsRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"g\n\x11ListTestsResponse\x12\x39\n\x05tests\x18\x01 \x03(\x0b\x32*.yandex.cloud.loadtesting.api.v1.test.Test\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xcf\x06\n\x0bTestService\x12\xa8\x01\n\x06\x43reate\x12\x32.yandex.cloud.loadtesting.api.v1.CreateTestRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x1f\n\x12\x43reateTestMetadata\x12\ttest.Test\x82\xd3\xe4\x93\x02\x1e\"\x19/loadtesting/api/v1/tests:\x01*\x12\x8f\x01\n\x03Get\x12/.yandex.cloud.loadtesting.api.v1.GetTestRequest\x1a*.yandex.cloud.loadtesting.api.v1.test.Test\"+\x82\xd3\xe4\x93\x02%\x12#/loadtesting/api/v1/tests/{test_id}\x12\xb1\x01\n\x04Stop\x12\x30.yandex.cloud.loadtesting.api.v1.StopTestRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*\x1d\n\x10StopTestMetadata\x12\ttest.Test\x82\xd3\xe4\x93\x02-\"(/loadtesting/api/v1/tests/{test_id}:stop:\x01*\x12\xbb\x01\n\x06\x44\x65lete\x12\x32.yandex.cloud.loadtesting.api.v1.DeleteTestRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*+\n\x12\x44\x65leteTestMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/loadtesting/api/v1/tests/{test_id}\x12\x90\x01\n\x04List\x12\x31.yandex.cloud.loadtesting.api.v1.ListTestsRequest\x1a\x32.yandex.cloud.loadtesting.api.v1.ListTestsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/loadtesting/api/v1/testsBv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting'
  _CREATETESTREQUEST.fields_by_name['folder_id']._options = None
  _CREATETESTREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETTESTREQUEST.fields_by_name['test_id']._options = None
  _GETTESTREQUEST.fields_by_name['test_id']._serialized_options = b'\350\3071\001'
  _TESTSERVICE.methods_by_name['Create']._options = None
  _TESTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\037\n\022CreateTestMetadata\022\ttest.Test\202\323\344\223\002\036\"\031/loadtesting/api/v1/tests:\001*'
  _TESTSERVICE.methods_by_name['Get']._options = None
  _TESTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002%\022#/loadtesting/api/v1/tests/{test_id}'
  _TESTSERVICE.methods_by_name['Stop']._options = None
  _TESTSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\035\n\020StopTestMetadata\022\ttest.Test\202\323\344\223\002-\"(/loadtesting/api/v1/tests/{test_id}:stop:\001*'
  _TESTSERVICE.methods_by_name['Delete']._options = None
  _TESTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteTestMetadata\022\025google.protobuf.Empty\202\323\344\223\002%*#/loadtesting/api/v1/tests/{test_id}'
  _TESTSERVICE.methods_by_name['List']._options = None
  _TESTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/loadtesting/api/v1/tests'
  _globals['_CREATETESTREQUEST']._serialized_start=395
  _globals['_CREATETESTREQUEST']._serialized_end=604
  _globals['_CREATETESTMETADATA']._serialized_start=606
  _globals['_CREATETESTMETADATA']._serialized_end=643
  _globals['_GETTESTREQUEST']._serialized_start=645
  _globals['_GETTESTREQUEST']._serialized_end=684
  _globals['_STOPTESTREQUEST']._serialized_start=686
  _globals['_STOPTESTREQUEST']._serialized_end=720
  _globals['_STOPTESTMETADATA']._serialized_start=722
  _globals['_STOPTESTMETADATA']._serialized_end=757
  _globals['_DELETETESTREQUEST']._serialized_start=759
  _globals['_DELETETESTREQUEST']._serialized_end=795
  _globals['_DELETETESTMETADATA']._serialized_start=797
  _globals['_DELETETESTMETADATA']._serialized_end=834
  _globals['_LISTTESTSREQUEST']._serialized_start=836
  _globals['_LISTTESTSREQUEST']._serialized_end=928
  _globals['_LISTTESTSRESPONSE']._serialized_start=930
  _globals['_LISTTESTSRESPONSE']._serialized_end=1033
  _globals['_TESTSERVICE']._serialized_start=1036
  _globals['_TESTSERVICE']._serialized_end=1883
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.mdb.kafka.v1 import common_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_common__pb2
from yandex.cloud.mdb.kafka.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/mdb/kafka/v1/cluster.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a google/protobuf/descriptor.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a&yandex/cloud/mdb/kafka/v1/common.proto\x1a+yandex/cloud/mdb/kafka/v1/maintenance.proto\"\x99\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12>\n\x06labels\x18\x06 \x03(\x0b\x32..yandex.cloud.mdb.kafka.v1.Cluster.LabelsEntry\x12\x43\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32..yandex.cloud.mdb.kafka.v1.Cluster.Environment\x12\x39\n\nmonitoring\x18\x08 \x03(\x0b\x32%.yandex.cloud.mdb.kafka.v1.Monitoring\x12\x35\n\x06\x63onfig\x18\t \x01(\x0b\x32%.yandex.cloud.mdb.kafka.v1.ConfigSpec\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12\x39\n\x06health\x18\x0b \x01(\x0e\x32).yandex.cloud.mdb.kafka.v1.Cluster.Health\x12\x39\n\x06status\x18\x0c \x01(\x0e\x32).yandex.cloud.mdb.kafka.v1.Cluster.Status\x12\x1a\n\x12security_group_ids\x18\r \x03(\t\x12\x16\n\x0ehost_group_ids\x18\x0e \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0f \x01(\x08\x12H\n\x12maintenance_window\x18\x10 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.MaintenanceWindow\x12J\n\x11planned_operation\x18\x11 \x01(\x0b\x32/.yandex.cloud.mdb.kafka.v1.MaintenanceOperation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\x9f\x06\n\nConfigSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12:\n\x05kafka\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.kafka.v1.ConfigSpec.Kafka\x12\x42\n\tzookeeper\x18\x03 \x01(\x0b\x32/.yandex.cloud.mdb.kafka.v1.ConfigSpec.Zookeeper\x12\x0f\n\x07zone_id\x18\x04 \x03(\t\x12\x32\n\rbrokers_count\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x18\n\x10\x61ssign_public_ip\x18\x06 \x01(\x08\x12\x1c\n\x10unmanaged_topics\x18\x07 \x01(\x08\x42\x02\x18\x01\x12\x17\n\x0fschema_registry\x18\x08 \x01(\x08\x12\x31\n\x06\x61\x63\x63\x65ss\x18\t \x01(\x0b\x32!.yandex.cloud.mdb.kafka.v1.Access\x12L\n\x0frest_api_config\x18\n \x01(\x0b\x32\x33.yandex.cloud.mdb.kafka.v1.ConfigSpec.RestAPIConfig\x1a\x80\x02\n\x05Kafka\x12\x37\n\tresources\x18\x01 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.Resources\x12V\n\x10kafka_config_2_8\x18\x04 \x01(\x0b\x32).yandex.cloud.mdb.kafka.v1.KafkaConfig2_8H\x00R\x0fkafkaConfig_2_8\x12P\n\x0ekafka_config_3\x18\x05 \x01(\x0b\x32\'.yandex.cloud.mdb.kafka.v1.KafkaConfig3H\x00R\rkafkaConfig_3B\x0e\n\x0ckafka_configJ\x04\x08\x02\x10\x04\x1a\x44\n\tZookeeper\x12\x37\n\tresources\x18\x01 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.Resources\x1a \n\rRestAPIConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"\xc0\t\n\x0eKafkaConfig2_8\x12\x44\n\x10\x63ompression_type\x18\x01 \x01(\x0e\x32*.yandex.cloud.mdb.kafka.v1.CompressionType\x12@\n\x1blog_flush_interval_messages\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15log_flush_interval_ms\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x1flog_flush_scheduler_interval_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13log_retention_bytes\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13log_retention_hours\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15log_retention_minutes\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x10log_retention_ms\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11log_segment_bytes\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0flog_preallocate\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x18socket_send_buffer_bytes\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bsocket_receive_buffer_bytes\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x19\x61uto_create_topics_enable\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0enum_partitions\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1a\x64\x65\x66\x61ult_replication_factor\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11message_max_bytes\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17replica_fetch_max_bytes\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x19\n\x11ssl_cipher_suites\x18\x12 \x03(\t\x12>\n\x19offsets_retention_minutes\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12I\n\x17sasl_enabled_mechanisms\x18\x14 \x03(\x0e\x32(.yandex.cloud.mdb.kafka.v1.SaslMechanism\"\xbe\t\n\x0cKafkaConfig3\x12\x44\n\x10\x63ompression_type\x18\x01 \x01(\x0e\x32*.yandex.cloud.mdb.kafka.v1.CompressionType\x12@\n\x1blog_flush_interval_messages\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15log_flush_interval_ms\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x1flog_flush_scheduler_interval_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13log_retention_bytes\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13log_retention_hours\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15log_retention_minutes\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x10log_retention_ms\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11log_segment_bytes\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0flog_preallocate\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x18socket_send_buffer_bytes\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bsocket_receive_buffer_bytes\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x19\x61uto_create_topics_enable\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0enum_partitions\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1a\x64\x65\x66\x61ult_replication_factor\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11message_max_bytes\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17replica_fetch_max_bytes\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x19\n\x11ssl_cipher_suites\x18\x12 \x03(\t\x12>\n\x19offsets_retention_minutes\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12I\n\x17sasl_enabled_mechanisms\x18\x14 \x03(\x0e\x32(.yandex.cloud.mdb.kafka.v1.SaslMechanism\"\x83\x03\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x32\n\x04role\x18\x04 \x01(\x0e\x32$.yandex.cloud.mdb.kafka.v1.Host.Role\x12\x37\n\tresources\x18\x05 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.Resources\x12\x36\n\x06health\x18\x06 \x01(\x0e\x32&.yandex.cloud.mdb.kafka.v1.Host.Health\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\"6\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\t\n\x05KAFKA\x10\x01\x12\r\n\tZOOKEEPER\x10\x02\"8\n\x06Health\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03J\x04\x08\x07\x10\x08\"\x1f\n\x06\x41\x63\x63\x65ss\x12\x15\n\rdata_transfer\x18\x01 \x01(\x08\x42\x64\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _CLUSTER_LABELSENTRY._options = None
  _CLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _CONFIGSPEC.fields_by_name['unmanaged_topics']._options = None
  _CONFIGSPEC.fields_by_name['unmanaged_topics']._serialized_options = b'\030\001'
  _globals['_CLUSTER']._serialized_start=255
  _globals['_CLUSTER']._serialized_end=1304
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=996
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1041
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1043
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1116
  _globals['_CLUSTER_HEALTH']._serialized_start=1118
  _globals['_CLUSTER_HEALTH']._serialized_end=1181
  _globals['_CLUSTER_STATUS']._serialized_start=1183
  _globals['_CLUSTER_STATUS']._serialized_end=1304
  _globals['_MONITORING']._serialized_start=1306
  _globals['_MONITORING']._serialized_end=1367
  _globals['_CONFIGSPEC']._serialized_start=1370
  _globals['_CONFIGSPEC']._serialized_end=2169
  _globals['_CONFIGSPEC_KAFKA']._serialized_start=1809
  _globals['_CONFIGSPEC_KAFKA']._serialized_end=2065
  _globals['_CONFIGSPEC_ZOOKEEPER']._serialized_start=2067
  _globals['_CONFIGSPEC_ZOOKEEPER']._serialized_end=2135
  _globals['_CONFIGSPEC_RESTAPICONFIG']._serialized_start=2137
  _globals['_CONFIGSPEC_RESTAPICONFIG']._serialized_end=2169
  _globals['_RESOURCES']._serialized_start=2171
  _globals['_RESOURCES']._serialized_end=2251
  _globals['_KAFKACONFIG2_8']._serialized_start=2254
  _globals['_KAFKACONFIG2_8']._serialized_end=3470
  _globals['_KAFKACONFIG3']._serialized_start=3473
  _globals['_KAFKACONFIG3']._serialized_end=4687
  _globals['_HOST']._serialized_start=4690
  _globals['_HOST']._serialized_end=5077
  _globals['_HOST_ROLE']._serialized_start=4959
  _globals['_HOST_ROLE']._serialized_end=5013
  _globals['_HOST_HEALTH']._serialized_start=5015
  _globals['_HOST_HEALTH']._serialized_end=5071
  _globals['_ACCESS']._serialized_start=5079
  _globals['_ACCESS']._serialized_end=5110
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadbalancer/v1/target_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.loadbalancer.v1 import target_group_pb2 as yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_target__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/loadbalancer/v1/target_group_service.proto\x12\x1cyandex.cloud.loadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a/yandex/cloud/loadbalancer/v1/target_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\">\n\x15GetTargetGroupRequest\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x94\x01\n\x17ListTargetGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"u\n\x18ListTargetGroupsResponse\x12@\n\rtarget_groups\x18\x01 \x03(\x0b\x32).yandex.cloud.loadbalancer.v1.TargetGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa7\x03\n\x18\x43reateTargetGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x42.yandex.cloud.loadbalancer.v1.CreateTargetGroupRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\tregion_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x35\n\x07targets\x18\x07 \x03(\x0b\x32$.yandex.cloud.loadbalancer.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07\"4\n\x19\x43reateTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\xbb\x03\n\x18UpdateTargetGroupRequest\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x42.yandex.cloud.loadbalancer.v1.UpdateTargetGroupRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x35\n\x07targets\x18\x06 \x03(\x0b\x32$.yandex.cloud.loadbalancer.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x19UpdateTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"A\n\x18\x44\x65leteTargetGroupRequest\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x19\x44\x65leteTargetGroupMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"z\n\x11\x41\x64\x64TargetsRequest\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x07targets\x18\x02 \x03(\x0b\x32$.yandex.cloud.loadbalancer.v1.TargetB\x07\x82\xc8\x31\x03>=1\"-\n\x12\x41\x64\x64TargetsMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"}\n\x14RemoveTargetsRequest\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x07targets\x18\x02 \x03(\x0b\x32$.yandex.cloud.loadbalancer.v1.TargetB\x07\x82\xc8\x31\x03>=1\"0\n\x15RemoveTargetsMetadata\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\"\x87\x01\n ListTargetGroupOperationsRequest\x12%\n\x0ftarget_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n!ListTargetGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbd\x0c\n\x12TargetGroupService\x12\x9f\x01\n\x03Get\x12\x33.yandex.cloud.loadbalancer.v1.GetTargetGroupRequest\x1a).yandex.cloud.loadbalancer.v1.TargetGroup\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/load-balancer/v1/targetGroups/{target_group_id}\x12\x9d\x01\n\x04List\x12\x35.yandex.cloud.loadbalancer.v1.ListTargetGroupsRequest\x1a\x36.yandex.cloud.loadbalancer.v1.ListTargetGroupsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/load-balancer/v1/targetGroups\x12\xba\x01\n\x06\x43reate\x12\x36.yandex.cloud.loadbalancer.v1.CreateTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*(\n\x19\x43reateTargetGroupMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02#\"\x1e/load-balancer/v1/targetGroups:\x01*\x12\xcc\x01\n\x06Update\x12\x36.yandex.cloud.loadbalancer.v1.UpdateTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*(\n\x19UpdateTargetGroupMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02\x35\x32\x30/load-balancer/v1/targetGroups/{target_group_id}:\x01*\x12\xd3\x01\n\x06\x44\x65lete\x12\x36.yandex.cloud.loadbalancer.v1.DeleteTargetGroupRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*2\n\x19\x44\x65leteTargetGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x32*0/load-balancer/v1/targetGroups/{target_group_id}\x12\xcd\x01\n\nAddTargets\x12/.yandex.cloud.loadbalancer.v1.AddTargetsRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*!\n\x12\x41\x64\x64TargetsMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02@\";/load-balancer/v1/targetGroups/{target_group_id}:addTargets:\x01*\x12\xd9\x01\n\rRemoveTargets\x12\x32.yandex.cloud.loadbalancer.v1.RemoveTargetsRequest\x1a!.yandex.cloud.operation.Operation\"q\xb2\xd2*$\n\x15RemoveTargetsMetadata\x12\x0bTargetGroup\x82\xd3\xe4\x93\x02\x43\">/load-balancer/v1/targetGroups/{target_group_id}:removeTargets:\x01*\x12\xd6\x01\n\x0eListOperations\x12>.yandex.cloud.loadbalancer.v1.ListTargetGroupOperationsRequest\x1a?.yandex.cloud.loadbalancer.v1.ListTargetGroupOperationsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/load-balancer/v1/targetGroups/{target_group_id}/operationsBq\n yandex.cloud.api.loadbalancer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadbalancer/v1;loadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadbalancer.v1.target_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.loadbalancer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadbalancer/v1;loadbalancer'
  _GETTARGETGROUPREQUEST.fields_by_name['target_group_id']._options = None
  _GETTARGETGROUPREQUEST.fields_by_name['target_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTTARGETGROUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTTARGETGROUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTTARGETGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTTARGETGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTTARGETGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTTARGETGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTTARGETGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTTARGETGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATETARGETGROUPREQUEST_LABELSENTRY._options = None
  _CREATETARGETGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATETARGETGROUPREQUEST.fields_by_name['folder_id']._options = None
  _CREATETARGETGROUPREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATETARGETGROUPREQUEST.fields_by_name['name']._options = None
  _CREATETARGETGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATETARGETGROUPREQUEST.fields_by_name['description']._options = None
  _CREATETARGETGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATETARGETGROUPREQUEST.fields_by_name['labels']._options = None
  _CREATETARGETGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATETARGETGROUPREQUEST.fields_by_name['region_id']._options = None
  _CREATETARGETGROUPREQUEST.fields_by_name['region_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATETARGETGROUPREQUEST_LABELSENTRY._options = None
  _UPDATETARGETGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATETARGETGROUPREQUEST.fields_by_name['target_group_id']._options = None
  _UPDATETARGETGROUPREQUEST.fields_by_name['target_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATETARGETGROUPREQUEST.fields_by_name['name']._options = None
  _UPDATETARGETGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATETARGETGROUPREQUEST.fields_by_name['description']._options = None
  _UPDATETARGETGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATETARGETGROUPREQUEST.fields_by_name['labels']._options = None
  _UPDATETARGETGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _DELETETARGETGROUPREQUEST.fields_by_name['target_group_id']._options = None
  _DELETETARGETGROUPREQUEST.fields_by_name['target_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDTARGETSREQUEST.fields_by_name['target_group_id']._options = None
  _ADDTARGETSREQUEST.fields_by_name['target_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDTARGETSREQUEST.fields_by_name['targets']._options = None
  _ADDTARGETSREQUEST.fields_by_name['targets']._serialized_options = b'\202\3101\003>=1'
  _REMOVETARGETSREQUEST.fields_by_name['target_group_id']._options = None
  _REMOVETARGETSREQUEST.fields_by_name['target_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REMOVETARGETSREQUEST.fields_by_name['targets']._options = None
  _REMOVETARGETSREQUEST.fields_by_name['targets']._serialized_options = b'\202\3101\003>=1'
  _LISTTARGETGROUPOPERATIONSREQUEST.fields_by_name['target_group_id']._options = None
  _LISTTARGETGROUPOPERATIONSREQUEST.fields_by_name['target_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTTARGETGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTTARGETGROUPOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTTARGETGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTTARGETGROUPOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _TARGETGROUPSERVICE.methods_by_name['Get']._options = None
  _TARGETGROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0022\0220/load-balancer/v1/targetGroups/{target_group_id}'
  _TARGETGROUPSERVICE.methods_by_name['List']._options = None
  _TARGETGROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002 \022\036/load-balancer/v1/targetGroups'
  _TARGETGROUPSERVICE.methods_by_name['Create']._options = None
  _TARGETGROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateTargetGroupMetadata\022\013TargetGroup\202\323\344\223\002#\"\036/load-balancer/v1/targetGroups:\001*'
  _TARGETGROUPSERVICE.methods_by_name['Update']._options = None
  _TARGETGROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateTargetGroupMetadata\022\013TargetGroup\202\323\344\223\002520/load-balancer/v1/targetGroups/{target_group_id}:\001*'
  _TARGETGROUPSERVICE.methods_by_name['Delete']._options = None
  _TARGETGROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteTargetGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0022*0/load-balancer/v1/targetGroups/{target_group_id}'
  _TARGETGROUPSERVICE.methods_by_name['AddTargets']._options = None
  _TARGETGROUPSERVICE.methods_by_name['AddTargets']._serialized_options = b'\262\322*!\n\022AddTargetsMetadata\022\013TargetGroup\202\323\344\223\002@\";/load-balancer/v1/targetGroups/{target_group_id}:addTargets:\001*'
  _TARGETGROUPSERVICE.methods_by_name['RemoveTargets']._options = None
  _TARGETGROUPSERVICE.methods_by_name['RemoveTargets']._serialized_options = b'\262\322*$\n\025RemoveTargetsMetadata\022\013TargetGroup\202\323\344\223\002C\">/load-balancer/v1/targetGroups/{target_group_id}:removeTargets:\001*'
  _TARGETGROUPSERVICE.methods_by_name['ListOperations']._options = None
  _TARGETGROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002=\022;/load-balancer/v1/targetGroups/{target_group_id}/operations'
  _globals['_GETTARGETGROUPREQUEST']._serialized_start=307
  _globals['_GETTARGETGROUPREQUEST']._serialized_end=369
  _globals['_LISTTARGETGROUPSREQUEST']._serialized_start=372
  _globals['_LISTTARGETGROUPSREQUEST']._serialized_end=520
  _globals['_LISTTARGETGROUPSRESPONSE']._serialized_start=522
  _globals['_LISTTARGETGROUPSRESPONSE']._serialized_end=639
  _globals['_CREATETARGETGROUPREQUEST']._serialized_start=642
  _globals['_CREATETARGETGROUPREQUEST']._serialized_end=1065
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._serialized_start=1014
  _globals['_CREATETARGETGROUPREQUEST_LABELSENTRY']._serialized_end=1059
  _globals['_CREATETARGETGROUPMETADATA']._serialized_start=1067
  _globals['_CREATETARGETGROUPMETADATA']._serialized_end=1119
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_start=1122
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_end=1565
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._serialized_start=1014
  _globals['_UPDATETARGETGROUPREQUEST_LABELSENTRY']._serialized_end=1059
  _globals['_UPDATETARGETGROUPMETADATA']._serialized_start=1567
  _globals['_UPDATETARGETGROUPMETADATA']._serialized_end=1619
  _globals['_DELETETARGETGROUPREQUEST']._serialized_start=1621
  _globals['_DELETETARGETGROUPREQUEST']._serialized_end=1686
  _globals['_DELETETARGETGROUPMETADATA']._serialized_start=1688
  _globals['_DELETETARGETGROUPMETADATA']._serialized_end=1740
  _globals['_ADDTARGETSREQUEST']._serialized_start=1742
  _globals['_ADDTARGETSREQUEST']._serialized_end=1864
  _globals['_ADDTARGETSMETADATA']._serialized_start=1866
  _globals['_ADDTARGETSMETADATA']._serialized_end=1911
  _globals['_REMOVETARGETSREQUEST']._serialized_start=1913
  _globals['_REMOVETARGETSREQUEST']._serialized_end=2038
  _globals['_REMOVETARGETSMETADATA']._serialized_start=2040
  _globals['_REMOVETARGETSMETADATA']._serialized_end=2088
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST']._serialized_start=2091
  _globals['_LISTTARGETGROUPOPERATIONSREQUEST']._serialized_end=2226
  _globals['_LISTTARGETGROUPOPERATIONSRESPONSE']._serialized_start=2228
  _globals['_LISTTARGETGROUPOPERATIONSRESPONSE']._serialized_end=2343
  _globals['_TARGETGROUPSERVICE']._serialized_start=2346
  _globals['_TARGETGROUPSERVICE']._serialized_end=3943
# @@protoc_insertion_point(module_scope)
